import React, { useContext, useEffect } from "react";
import "@scss/transactions.scss";
import Table from "@components/Transactions/Table"
import userContext from "@ts/userContext"
import AppBar from "@theme/modules/components/AppBar";
import Toolbar from "@theme/modules/components/Toolbar";
import Typography from "@theme/modules/components/Typography";
import { Box, Link, TextFieldProps, TextField } from "@mui/material";
import AccountCircleIcon from '@mui/icons-material/AccountCircle';
import { DesktopDatePicker } from '@mui/x-date-pickers/DesktopDatePicker';
import { useForm } from "react-hook-form";
import * as yup from "yup";
import { yupResolver } from "@hookform/resolvers/yup";
import { LocalizationProvider } from "@mui/x-date-pickers/LocalizationProvider/LocalizationProvider";
import dayjs, { Dayjs } from 'dayjs';
import { AdapterDayjs } from '@mui/x-date-pickers/AdapterDayjs';
import { getValue } from "@mui/system";



type Inputs = {
    startDate?: Date;
    endDate?: Date;
    minAmount?: number;
    maxAmount?: number;
    amountType?: "incoming" | "outgoing" | "both";
};


const schema = yup
    .object()
    .shape({
        startDate: yup.date().nullable().default(() => {return null}).typeError("Invalid date"),
        endDate: yup.date().nullable().typeError("Invalid date"),
        minAmount: yup.number().positive(),
        maxAmount: yup.number().positive(),
        amountType: yup.string().oneOf(["incoming", "outgoing", "both"]),
    })
    .required();


export default function Transactions() {
    const user = useContext(userContext)

    const {
        register,
        formState: { errors },
        handleSubmit,
        getValues
    } = useForm<Inputs>({
        resolver: yupResolver(schema),
    });


    const { ref: startDateRef, ...startDateRegisterProps } = register("startDate");
    console.log(startDateRegisterProps)

    const startDatePickerProps = {
        ...startDateRegisterProps,
        inputRef: startDateRef,
        value: getValues("startDate"),
        className: "input datePicker start",
        label: "Starting Date",
        name: "endDate",
        emptyLabel: "hello world",
        inputFormat: "DD/MM/YYYY",
        renderInput: (params: TextFieldProps) => <TextField {...params} />
    }
    
    const { ref: endDateRef, ...endDateRegisterProps } = register("endDate");

    const endDatePickerProps = {
        ...endDateRegisterProps,
        inputRef: endDateRef,
        value: getValues("endDate"),
        className: "input datePicker end",
        label: "Ending Date",
        name: "endDate",
        inputFormat: "DD/MM/YYYY",
        error: !!errors.minAmount,
        helperText: errors?.minAmount?.message,
        renderInput: (params: TextFieldProps) => <TextField {...params} />
    }

    const { ref: minAmountRef, ...minAmountRegisterProps } = register("minAmount");

    const minAmountProps = {
        ...minAmountRegisterProps,
        inputRef: minAmountRef,
        className: "input min",
        label: "Minimum Amount",
        name: "minAmount",
        error: !!errors.minAmount,
        helperText: errors?.minAmount?.message,
    }

    const { ref: maxAmountRef, ...maxAmountRegisterProps } = register("maxAmount");

    const maxAmountProps = {
        ...maxAmountRegisterProps,
        inputRef: maxAmountRef,
        className: "input max",
        label: "Maximum Amount",
        name: "maxAmount",
        error: !!errors.maxAmount,
        helperText: errors?.maxAmount?.message,
    }

    return (
        <div id="tablePage">
            <AppBar position="fixed" sx={{ background: "#28282a" }}>
                <Toolbar className="toolbar" sx={{ justifyContent: 'space-between' }}>
                    <Box className="box left" />
                    <Typography variant="h3" >
                        Transactions
                    </Typography>
                    <Box className="box right">
                        <Link variant="h6" className="link" href="/">
                            {user.name}
                        </Link>
                        <AccountCircleIcon className="icon" />
                    </Box>
                </Toolbar>
            </AppBar>
            <aside>
                <form>
                    <Typography variant="h5">
                        Filters
                    </Typography>
                    <Typography variant="h6">
                        Dates
                    </Typography>
                    <LocalizationProvider dateAdapter={AdapterDayjs}>
                        <DesktopDatePicker {...startDatePickerProps} />
                        <DesktopDatePicker {...endDatePickerProps} />
                    </LocalizationProvider>
                    <Typography variant="h6">
                        Transactions
                    </Typography>
                    <TextField {...minAmountProps}></TextField>
                    <TextField {...maxAmountProps}></TextField>
                </form>
            </aside>
            <main>
                <Table />
            </main>
            <footer>
                footer
            </footer>
        </div>
    );
}
